==> dnet-mapreduce-jobs-0.0.9.4-20160930.104818-1-sources.jar: eu/dnetlib/data/mapreduce/hbase/broker/OAVersionEventFactory.java <==
package eu.dnetlib.data.mapreduce.hbase.broker;

import java.io.IOException;
import java.util.List;
import java.util.Set;

import com.google.common.base.Predicate;
import com.google.common.collect.Iterables;
import com.google.common.collect.Lists;
import eu.dnetlib.broker.objects.OpenAireEventPayload;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.HighlightFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.OpenAireEventPayloadFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.model.EventMessage;
import eu.dnetlib.data.proto.OafProtos.Oaf;
import eu.dnetlib.data.proto.ResultProtos.Result.Instance;
import org.apache.commons.lang.StringUtils;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Reducer.Context;

import static eu.dnetlib.data.mapreduce.hbase.broker.mapping.EventFactory.asEvent;
import static eu.dnetlib.data.mapreduce.util.OafHbaseUtils.getKey;

/**
 * Created by claudio on 26/07/16.
 */
public class OAVersionEventFactory {

	protected Text tKey = new Text("");

	public static void process(final Context context, final Oaf current, final Oaf other, final float trust, final Set<String> untrustedOaDsList) throws IOException, InterruptedException {
		new OAVersionEventFactory().processOAVersion(context, current, other, trust, untrustedOaDsList);
	}

	private void processOAVersion(final Context context, final Oaf current, final Oaf other, final float trust, final Set<String> untrustedOaDsList)
			throws IOException, InterruptedException {
		final String otherDsId = StringUtils.substringAfter(getKey(other.getEntity().getCollectedfromList()), "|");

		//OPEN ACCESS VERSION
		if (!untrustedOaDsList.contains(otherDsId)) {

			if (hasAccess(other, "OPEN", false)) {

				//MORE
				doProcessOAVersion(context, current, other, Topic.MORE_OA_VERSION, trust);

				//MISSING
				if (!hasAccess(current, "OPEN", true)) {
					doProcessOAVersion(context, current, other, Topic.MISSING_OA_VERSION, trust);
				}
			}
		}

	}

	private void doProcessOAVersion(final Context context, final Oaf current, final Oaf other, final Topic topic, final float trust) throws IOException, InterruptedException {
		final Oaf.Builder prototype = Oaf.newBuilder(current);
		final Iterable<Instance> i = Iterables.filter(other.getEntity().getResult().getInstanceList(), new Predicate<Instance>() {
			@Override
			public boolean apply(final Instance i) {
				return "OPEN".equalsIgnoreCase(i.getLicence().getClassid());
			}
		});
		prototype.getEntityBuilder().getResultBuilder().addAllInstance(i);

		final Oaf oaf = prototype.build();

		final EventMessage event = asEvent(oaf.getEntity(), topic, other.getEntity(), trust);
		final OpenAireEventPayload payload = OpenAireEventPayloadFactory.fromOAF(oaf.getEntity(), other.getEntity(), trust);
		event.setPayload(HighlightFactory.highlightEnrichOa(payload, Lists.newArrayList(i)).toJSON());

		context.write(tKey, new Text(event.toString()));
		context.getCounter("event", topic.getValue()).increment(1);
	}

	private boolean hasAccess(final Oaf oaf, final String access, final boolean strict) {
		final Predicate<Instance> p = new Predicate<Instance>() {
			@Override
			public boolean apply(final Instance i) {
				return access.equalsIgnoreCase(i.getLicence().getClassid());
			}
		};
		final List<Instance> i = oaf.getEntity().getResult().getInstanceList();
		return strict ? Iterables.all(i, p) : Iterables.any(i, p);
	}

}

==> dnet-mapreduce-jobs-1.0.0-20170627.153716-10-sources.jar: eu/dnetlib/data/mapreduce/hbase/broker/OAVersionEventFactory.java <==
package eu.dnetlib.data.mapreduce.hbase.broker;

import static eu.dnetlib.data.mapreduce.hbase.broker.mapping.EventFactory.asEvent;
import static eu.dnetlib.data.mapreduce.util.OafHbaseUtils.getKey;

import java.io.IOException;
import java.util.List;
import java.util.Set;

import org.apache.commons.lang.StringUtils;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Reducer.Context;
import org.dom4j.DocumentException;

import com.google.common.base.Predicate;
import com.google.common.collect.Iterables;
import com.google.common.collect.Lists;

import eu.dnetlib.broker.objects.OpenAireEventPayload;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.HighlightFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.mapping.OpenAireEventPayloadFactory;
import eu.dnetlib.data.mapreduce.hbase.broker.model.EventMessage;
import eu.dnetlib.data.proto.OafProtos.Oaf;
import eu.dnetlib.data.proto.ResultProtos.Result.Instance;

/**
 * Created by claudio on 26/07/16.
 */
public class OAVersionEventFactory {

	protected Text tKey = new Text("");

	public static void process(final Context context, final Oaf current, final Oaf other, final float trust, final Set<String> untrustedOaDsList)
			throws IOException, InterruptedException, DocumentException {
		new OAVersionEventFactory().processOAVersion(context, current, other, trust, untrustedOaDsList);
	}

	private void processOAVersion(final Context context, final Oaf current, final Oaf other, final float trust, final Set<String> untrustedOaDsList)
			throws IOException, InterruptedException, DocumentException {
		final String otherDsId = StringUtils.substringAfter(getKey(other.getEntity().getCollectedfromList()), "|");

		// OPEN ACCESS VERSION
		if (!untrustedOaDsList.contains(otherDsId)) {

			if (hasAccess(other, "OPEN", false)) {

				// MORE
				doProcessOAVersion(context, current, other, Topic.ENRICH_MORE_OA_VERSION, trust);

				// MISSING
				if (!hasAccess(current, "OPEN", true)) {
					doProcessOAVersion(context, current, other, Topic.ENRICH_MISSING_OA_VERSION, trust);
				}
			}
		}

	}

	private void doProcessOAVersion(final Context context, final Oaf current, final Oaf other, final Topic topic, final float trust)
			throws IOException, InterruptedException, DocumentException {
		final Oaf.Builder prototype = Oaf.newBuilder(current);
		final Iterable<Instance> i = Iterables.filter(other.getEntity().getResult().getInstanceList(), new Predicate<Instance>() {

			@Override
			public boolean apply(final Instance i) {
				return "OPEN".equalsIgnoreCase(i.getLicence().getClassid());
			}
		});
		prototype.getEntityBuilder().getResultBuilder().addAllInstance(i);

		final Oaf oaf = prototype.build();

		final OpenAireEventPayload payload =
				HighlightFactory.highlightEnrichOa(OpenAireEventPayloadFactory.fromOAF(oaf.getEntity(), other.getEntity(), trust), Lists.newArrayList(i));
		final EventMessage event = asEvent(oaf.getEntity(), topic, payload, other.getEntity(), trust);

		context.write(tKey, new Text(event.toString()));
		context.getCounter("event", topic.getValue()).increment(1);
	}

	private boolean hasAccess(final Oaf oaf, final String access, final boolean strict) {
		final Predicate<Instance> p = new Predicate<Instance>() {

			@Override
			public boolean apply(final Instance i) {
				return access.equalsIgnoreCase(i.getLicence().getClassid());
			}
		};
		final List<Instance> i = oaf.getEntity().getResult().getInstanceList();
		return strict ? Iterables.all(i, p) : Iterables.any(i, p);
	}

}
